==> ready4_0.1.9.tar.gz: ready4/README.md <==
# ready4

## Implement Modular and Open-Source Health Economic Models

<!-- badges: start -->
[![Lifecycle: experimental](https://img.shields.io/badge/lifecycle-experimental-orange.svg)](https://lifecycle.r-lib.org/articles/stages.html#experimental)
[![ready4](https://img.shields.io/badge/ready4-foundation-coral?style=flat&labelColor=black&logo=data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAAFzUkdCAK7OHOkAAAAEZ0FNQQAAsY8L/GEFAAAACXBIWXMAABYlAAAWJQFJUiTwAAAAIXRFWHRDcmVhdGlvbiBUaW1lADIwMjI6MDM6MDcgMTY6MTM6NTPZeG5UAAABa0lEQVQ4T4WT607CQBCFpyUi3qIR0eAfNfCi/vENfEgENIAIlcJ6vr1oLaZOerJzdst0zpklc49nznqHZs6ZfWwDem1xM1sqXwtXkb8rL4SuOLEoLXPPXWfD01Dg9dPsrTQbngQ+EZ+LDyIfiy/FHyIfFZbbTslWKOOqxx/uWBPSfp07FahGlqlNfWGqL9HNfBO+CAfwdO55WS8g4MFML834sfJVA9e7vwsg50aGohncdmRojV9XeL+jArRNmZxVSJ4Acj3NHqARdyeFJqC2KJiCfKE9zsfxnNYTl5TcCtmNMcwY/ZXf+3wdzzVza2vj4iCaq3d1R/bvwVSH6IPjNIUHx0FSNZA7WquDqOVb35+eiO8h7Oe+vRfp0a3yGtFMDuiAIg2R20YaVwJ3Hj+4kehO/J/I7VJ/jHtpvBP6mrHnR4EzdyQ0xI8HhM8jUiChxVpDK3iVuadzx43yRdI4E2d0gNtX74TCs419AR8YEST/cHPBAAAAAElFTkSuQmCC)](https://www.ready4-dev.com/docs/software/libraries/types/framework/)
[![R-CMD-check](https://github.com/ready4-dev/ready4/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/ready4-dev/ready4/actions/workflows/R-CMD-check.yaml)
[![test-coverage](https://github.com/ready4-dev/ready4/actions/workflows/test-coverage.yaml/badge.svg)](https://github.com/ready4-dev/ready4/actions/workflows/test-coverage.yaml)
[![codecov](https://codecov.io/gh/ready4-dev/ready4/branch/main/graph/badge.svg)](https://app.codecov.io/gh/ready4-dev/ready4)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.5606250.svg)](https://doi.org/10.5281/zenodo.5606250)
[![CRAN status](https://www.r-pkg.org/badges/version/ready4)](https://CRAN.R-project.org/package=ready4)
<!-- badges: end -->

Programming syntax, a template model module and tools to help
maintain a modular and open-source health economic model's project
documentation website.  These elements are the foundation for a
prototype software framework to support replicable and transferable
health economic models. The software framework is extended by other R
libraries.  For detailed documentation about the framework and how to
use it visit <https://www.ready4-dev.com/>. For a background to the
methodological issues that the framework is attempting to help solve,
see Hamilton et al. (2024) <https://arxiv.org/abs/2310.14138>.

To install a development version of this software, run the following commands in your R console:

```r
utils::install.packages("devtools")

devtools::install_github("ready4-dev/ready4")

```

==> ready4_0.1.14.tar.gz: ready4/README.md <==
# ready4

## Develop and Use Modular Health Economic Models

<!-- badges: start -->
[![Lifecycle: experimental](https://img.shields.io/badge/lifecycle-experimental-orange.svg)](https://lifecycle.r-lib.org/articles/stages.html#experimental)
[![ready4](https://img.shields.io/badge/ready4-foundation-coral?style=flat&labelColor=black&logo=data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAABHNCSVQICAgIfAhkiAAAAAFzUkdCAK7OHOkAAAAEZ0FNQQAAsY8L/GEFAAAACXBIWXMAABYlAAAWJQFJUiTwAAAAIXRFWHRDcmVhdGlvbiBUaW1lADIwMjI6MDM6MDcgMTY6MTM6NTPZeG5UAAABa0lEQVQ4T4WT607CQBCFpyUi3qIR0eAfNfCi/vENfEgENIAIlcJ6vr1oLaZOerJzdst0zpklc49nznqHZs6ZfWwDem1xM1sqXwtXkb8rL4SuOLEoLXPPXWfD01Dg9dPsrTQbngQ+EZ+LDyIfiy/FHyIfFZbbTslWKOOqxx/uWBPSfp07FahGlqlNfWGqL9HNfBO+CAfwdO55WS8g4MFML834sfJVA9e7vwsg50aGohncdmRojV9XeL+jArRNmZxVSJ4Acj3NHqARdyeFJqC2KJiCfKE9zsfxnNYTl5TcCtmNMcwY/ZXf+3wdzzVza2vj4iCaq3d1R/bvwVSH6IPjNIUHx0FSNZA7WquDqOVb35+eiO8h7Oe+vRfp0a3yGtFMDuiAIg2R20YaVwJ3Hj+4kehO/J/I7VJ/jHtpvBP6mrHnR4EzdyQ0xI8HhM8jUiChxVpDK3iVuadzx43yRdI4E2d0gNtX74TCs419AR8YEST/cHPBAAAAAElFTkSuQmCC)](https://www.ready4-dev.com/docs/software/libraries/types/framework/)
[![R-CMD-check](https://github.com/ready4-dev/ready4/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/ready4-dev/ready4/actions/workflows/R-CMD-check.yaml)
[![test-coverage](https://github.com/ready4-dev/ready4/actions/workflows/test-coverage.yaml/badge.svg)](https://github.com/ready4-dev/ready4/actions/workflows/test-coverage.yaml)
[![codecov](https://app.codecov.io/gh/ready4-dev/ready4/branch/main/graph/badge.svg)](https://app.codecov.io/gh/ready4-dev/ready4)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.5606250.svg)](https://doi.org/10.5281/zenodo.5606250)
[![CRAN status](https://www.r-pkg.org/badges/version/ready4)](https://CRAN.R-project.org/package=ready4)
<!-- badges: end -->

A template model module, tools to help find model modules
derived from this template and a programming syntax to use these
modules in health economic analyses.  These elements are the
foundation for a prototype software framework for developing living
and transferable models and using those models in reproducible health
economic analyses. The software framework is extended by other R
libraries.  For detailed documentation about the framework and how to
use it visit <https://www.ready4-dev.com/>. For a background to the
methodological issues that the framework is attempting to help solve,
see Hamilton et al. (2024) <https://doi.org/10.1007/s40273-024-01378-8>.

To install a development version of this software, run the following commands in your R console:

```r
utils::install.packages("devtools")

devtools::install_github("ready4-dev/ready4")

```
